#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  svg2stl.py
#  
#  Copyright 2015 Philippe Bonnet <phil.bonnet@laposte.net>
#  
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#  
#  20/06/15	Phil_B	: Ajouter la gestion du chemin de stockage
#                     et de l'extension du fichier image

# standard library
import os
import sys
import re

import inkex
import subprocess
from PIL import Image
from litho3d_stl import STLConverter

class SvgConvert(inkex.Effect):
    """
    Convertir les champs texte d'un calque en image QRCode
    """
    def __init__(self):
        inkex.Effect.__init__(self)
        self.OptionParser.add_option("", "--active-tab", 
            action="store", type="string", dest="active_tab", 
            default="",     help="Defines which tab is active")
        self.OptionParser.add_option("", "--png_name",   
            action="store", type="string", dest="png_name",   
            default="",     help="Non du fichier image")
        self.OptionParser.add_option("", "--doc_opacity",   
            action="store", type="inkbool", dest="doc_opacity",   
            default=False,     help="")
        self.OptionParser.add_option("", "--png_show",   
            action="store", type="inkbool", dest="png_show",   
            default=False,     help="")
        self.stlc = STLConverter()
        
    def effect(self):
        """
        Méthode principale
        """
        if self.options.png_name[1:] != os.sep:
			self.options.png_name = os.environ['HOME']+os.sep+self.options.png_name
        if self.options.png_name[-4:].lower() != '.png':
			self.options.png_name += '.png'
        if self.options.active_tab == '"help"' :
            return
        if self.options.active_tab == '"opacity"' and self.options.doc_opacity:
            for i in self.document.getroot():
                if i.tag == inkex.addNS('namedview','sodipodi') :
                    #inkex.errormsg(i.get(inkex.addNS('pageopacity','inkscape')))
                    i.set(inkex.addNS('pageopacity','inkscape'),str(1.0))
                    #inkex.errormsg(i.get(inkex.addNS('pageopacity','inkscape')))
                    break
            return
        if self.options.active_tab == '"svg2png"' :

            res = subprocess.check_output([
                'inkscape',
                '--export-png=%s' %(self.options.png_name),
                '--export-dpi=150',
                '--without-gui',
                self.svg_file])
            if self.options.png_show: Image.open(self.options.png_name).show()
            self.stlc.load_image(self.options.png_name)
            self.stlc.create_stl(self.options.png_name)
        return

def main():
    svgconv = SvgConvert()
    svgconv.affect()
    return 0

if __name__ == '__main__':
	main()
